import {Plugin} from 'prosemirror-state'

function getNodeLength (node) {
  const text = node.textBetween(0, node.content.size, undefined, ' ')
  return text.length
}

export default function (maxLength) {
  return new Plugin({
    filterTransaction: (transaction, state) => {
      if (!transaction.docChanged) {
        return true
      }

      const oldLength = getNodeLength(state.doc)
      const newLength = getNodeLength(transaction.doc)

      if (newLength <= maxLength) {
        return true
      }

      if (newLength <= maxLength || newLength < oldLength) {
        return true
      }

      if (oldLength > maxLength && newLength > maxLength) {
        return false
      }

      const pos = transaction.selection.$head.pos
      const over = newLength - maxLength
      const from = pos - over
      const to = pos

      transaction.deleteRange(from, to)

      return true
    },
  })
}
