import Godo from '../src-js/godo'
import {test, expect} from 'vitest'

test('test create editor', async () => {
  const form = document.createElement('form')
  const textArea = document.createElement('textarea')
  form.appendChild(textArea)
  const godo = new Godo(textArea, {})
  expect(godo).not.toBe(undefined)
  expect(document.querySelector('.godo')).not.toBe(undefined)
})

test('test create godo element', async () => {
  const form = document.createElement('form')
  const editor = document.createElement('godo-editor')
  form.appendChild(editor)
  expect(document.querySelector('.godo')).not.toBe(undefined)
})

test('test create godo element with initial content', async () => {
  const form = document.createElement('form')
  document.appendChild(form)
  const editor = document.createElement('godo-editor')
  // check that the content is processed by the schema before being set
  editor.innerHTML = '<invalid-tag>Test content</invalid-tag>'
  form.appendChild(editor)

  expect(document.querySelector('godo-editor textarea').value).toBe('<p>Test content</p>')
  expect(editor.value).toBe('<p>Test content</p>')
  expect(document.querySelector('godo-editor .ProseMirror').innerHTML).toBe('<p>Test content</p>')
})

test('test godo no-edit attribute', async () => {
  const form = document.createElement('form')
  document.appendChild(form)
  const editor = document.createElement('godo-editor')
  form.appendChild(editor)
  expect(editor.view.editable).toBe(true)
  editor.setAttribute('no-edit', true)
  expect(editor.view.editable).toBe(false)
  editor.removeAttribute('no-edit')
  expect(editor.view.editable).toBe(true)
})

test('test godo-edior value property', async () => {
  const form = document.createElement('form')
  document.appendChild(form)
  const editor = document.createElement('godo-editor')
  form.appendChild(editor)

  expect(editor.value).toBe('')

  // check that the content is processed by the schema before being set
  editor.value = '<invalid-tag>Modified content</invalid-tag>'

  expect(editor.value).toBe('<p>Modified content</p>')
  expect(editor.querySelector('textarea').value).toBe('<p>Modified content</p>')
  expect(editor.querySelector('.ProseMirror').innerHTML).toBe('<p>Modified content</p>')

  editor.view.dispatch(editor.view.state.tr.insertText('Inserted content & '))
  expect(editor.value).toBe('<p>Inserted content & Modified content</p>')
  expect(editor.querySelector('.ProseMirror').innerHTML).toBe('<p>Inserted content & Modified content</p>')
})

test('test godo-editor maxlength property', async () => {
  document.write(`
    <form>
      <godo-editor maxlength="10">
      </godo-editor>
    </form>
  `)
  const editor = document.querySelector('godo-editor')

  editor.view.dispatch(editor.view.state.tr.insertText('This is too long'))
  expect(editor.value).toBe('<p>This is to</p>')
})

